@@ -49,6 +49,8 @@ private Q_SLOTS:
     void testSetupTeardown();
     void testStorageAccessFromPath();
     void testStorageAccessFromPath_data();
+    void testDeviceVendorProduct();
+    void testDeviceVendorProduct_data();
 
 private:
     Solid::Backends::Fake::FakeManager *fakeManager;
@@ -87,30 +89,30 @@ void SolidHwTest::testAllDevices()
 void SolidHwTest::testDeviceBasicFeatures()
 {
     // Retrieve a valid Device object
-    Solid::Device valid_dev("/org/kde/solid/fakehw/storage_model_solid_writer");
+    Solid::Device valid_dev(QStringLiteral("/org/kde/solid/fakehw/storage_model_solid_writer"));
 
     QCOMPARE(valid_dev.isValid(), true);
 
     // A few attempts at creating invalid Device objects
-    Solid::Device invalid_dev("uhoh? doesn't exist, I guess");
+    Solid::Device invalid_dev(QStringLiteral("uhoh? doesn't exist, I guess"));
     QCOMPARE(invalid_dev.isValid(), false);
     invalid_dev = Solid::Device(QString());
     QCOMPARE(invalid_dev.isValid(), false);
     invalid_dev = Solid::Device();
     QCOMPARE(invalid_dev.isValid(), false);
 
-    QCOMPARE(valid_dev.udi(), QString("/org/kde/solid/fakehw/storage_model_solid_writer"));
+    QCOMPARE(valid_dev.udi(), QStringLiteral("/org/kde/solid/fakehw/storage_model_solid_writer"));
     QCOMPARE(invalid_dev.udi(), QString());
 
     // Query properties
-    QCOMPARE(valid_dev.as<Solid::GenericInterface>()->propertyExists("name"), true);
-    QCOMPARE(valid_dev.as<Solid::GenericInterface>()->propertyExists("foo.bar"), false);
+    QCOMPARE(valid_dev.as<Solid::GenericInterface>()->propertyExists(QStringLiteral("name")), true);
+    QCOMPARE(valid_dev.as<Solid::GenericInterface>()->propertyExists(QStringLiteral("foo.bar")), false);
     QCOMPARE((QObject *)invalid_dev.as<Solid::GenericInterface>(), (QObject *)nullptr);
 
-    QCOMPARE(valid_dev.as<Solid::GenericInterface>()->property("name"), QVariant("Solid IDE DVD Writer"));
-    QVERIFY(!valid_dev.as<Solid::GenericInterface>()->property("foo.bar").isValid());
+    QCOMPARE(valid_dev.as<Solid::GenericInterface>()->property(QStringLiteral("name")), QStringLiteral("Solid IDE DVD Writer"));
+    QVERIFY(!valid_dev.as<Solid::GenericInterface>()->property(QStringLiteral("foo.bar")).isValid());
 
-    Solid::Backends::Fake::FakeDevice *fake_device = fakeManager->findDevice("/org/kde/solid/fakehw/storage_model_solid_writer");
+    Solid::Backends::Fake::FakeDevice *fake_device = fakeManager->findDevice(QStringLiteral("/org/kde/solid/fakehw/storage_model_solid_writer"));
     QMap<QString, QVariant> expected_properties = fake_device->allProperties();
 
     QCOMPARE(valid_dev.as<Solid::GenericInterface>()->allProperties(), expected_properties);
@@ -124,15 +126,15 @@ void SolidHwTest::testDeviceBasicFeatures()
     QCOMPARE(invalid_dev.isDeviceInterface(Solid::DeviceInterface::StorageDrive), false);
 
     // Query parent
-    QCOMPARE(valid_dev.parentUdi(), QString("/org/kde/solid/fakehw/pci_002_ide_1_0"));
-    QCOMPARE(valid_dev.parent().udi(), Solid::Device("/org/kde/solid/fakehw/pci_002_ide_1_0").udi());
+    QCOMPARE(valid_dev.parentUdi(), QStringLiteral("/org/kde/solid/fakehw/pci_002_ide_1_0"));
+    QCOMPARE(valid_dev.parent().udi(), Solid::Device(QStringLiteral("/org/kde/solid/fakehw/pci_002_ide_1_0")).udi());
 
     QVERIFY(!invalid_dev.parent().isValid());
     QVERIFY(invalid_dev.parentUdi().isEmpty());
 
     // Query vendor/product
-    QCOMPARE(valid_dev.vendor(), QString("Acme Corporation"));
-    QCOMPARE(valid_dev.product(), QString("Solid IDE DVD Writer"));
+    QCOMPARE(valid_dev.vendor(), QStringLiteral("Acme Corporation"));
+    QCOMPARE(valid_dev.product(), QStringLiteral("Solid IDE DVD Writer"));
 
     QCOMPARE(invalid_dev.vendor(), QString());
     QCOMPARE(invalid_dev.product(), QString());
@@ -140,47 +142,47 @@ void SolidHwTest::testDeviceBasicFeatures()
 
 void SolidHwTest::testManagerSignals()
 {
-    fakeManager->unplug("/org/kde/solid/fakehw/acpi_CPU0");
+    fakeManager->unplug(QStringLiteral("/org/kde/solid/fakehw/acpi_CPU0"));
 
     // Heh, we missed a processor in this system ;-)
     // We're going to add this device, and check that the signal has been
     // properly emitted by the manager
     QSignalSpy added(Solid::DeviceNotifier::instance(), SIGNAL(deviceAdded(QString)));
-    fakeManager->plug("/org/kde/solid/fakehw/acpi_CPU0");
+    fakeManager->plug(QStringLiteral("/org/kde/solid/fakehw/acpi_CPU0"));
     QCOMPARE(added.count(), 1);
-    QCOMPARE(added.at(0).at(0).toString(), QString("/org/kde/solid/fakehw/acpi_CPU0"));
+    QCOMPARE(added.at(0).at(0).toString(), QStringLiteral("/org/kde/solid/fakehw/acpi_CPU0"));
 
     // Moreover we check that the device is really available
-    Solid::Device cpu("/org/kde/solid/fakehw/acpi_CPU0");
+    Solid::Device cpu(QStringLiteral("/org/kde/solid/fakehw/acpi_CPU0"));
     QVERIFY(cpu.isValid());
 
     // Finally we remove the device and spy the corresponding signal again
     QSignalSpy removed(Solid::DeviceNotifier::instance(), SIGNAL(deviceRemoved(QString)));
-    fakeManager->unplug("/org/kde/solid/fakehw/acpi_CPU0");
+    fakeManager->unplug(QStringLiteral("/org/kde/solid/fakehw/acpi_CPU0"));
     QCOMPARE(added.count(), 1);
-    QCOMPARE(added.at(0).at(0).toString(), QString("/org/kde/solid/fakehw/acpi_CPU0"));
+    QCOMPARE(added.at(0).at(0).toString(), QStringLiteral("/org/kde/solid/fakehw/acpi_CPU0"));
 
     // The Device object should become automatically invalid
     QVERIFY(!cpu.isValid());
 
     // Restore original state
-    fakeManager->plug("/org/kde/solid/fakehw/acpi_CPU0");
+    fakeManager->plug(QStringLiteral("/org/kde/solid/fakehw/acpi_CPU0"));
 }
 
 void SolidHwTest::testDeviceSignals()
 {
     // A button is a nice device for testing state changes, isn't it?
-    Solid::Backends::Fake::FakeDevice *fake = fakeManager->findDevice("/org/kde/solid/fakehw/platform_floppy_0_storage_virt_volume");
-    Solid::Device device("/org/kde/solid/fakehw/platform_floppy_0_storage_virt_volume");
+    Solid::Backends::Fake::FakeDevice *fake = fakeManager->findDevice(QStringLiteral("/org/kde/solid/fakehw/platform_floppy_0_storage_virt_volume"));
+    Solid::Device device(QStringLiteral("/org/kde/solid/fakehw/platform_floppy_0_storage_virt_volume"));
 
     // We'll spy our floppy
     QSignalSpy condition_raised(device.as<Solid::GenericInterface>(), SIGNAL(conditionRaised(QString, QString)));
     QSignalSpy property_changed(device.as<Solid::GenericInterface>(), SIGNAL(propertyChanged(QMap<QString, int>)));
 
-    fake->setProperty("mountPoint", "/tmp.foo"); // The button is now pressed (modified property)
-    fake->raiseCondition("Floppy Closed", "Why not?"); // Since it's a LID we notify this change
-    fake->setProperty("hactar", 42); // We add a property
-    fake->removeProperty("hactar"); // We remove a property
+    fake->setProperty(QStringLiteral("mountPoint"), QStringLiteral("/tmp.foo")); // The button is now pressed (modified property)
+    fake->raiseCondition(QStringLiteral("Floppy Closed"), QStringLiteral("Why not?")); // Since it's a LID we notify this change
+    fake->setProperty(QStringLiteral("hactar"), 42); // We add a property
+    fake->removeProperty(QStringLiteral("hactar")); // We remove a property
 
     // 3 property changes occurred in the device
     QCOMPARE(property_changed.count(), 3);
@@ -190,51 +192,51 @@ void SolidHwTest::testDeviceSignals()
     // First one is a "PropertyModified" for "button.state"
     changes = property_changed.at(0).at(0).value<QMap<QString, int>>();
     QCOMPARE(changes.count(), 1);
-    QVERIFY(changes.contains("mountPoint"));
-    QCOMPARE(changes["mountPoint"], (int)Solid::GenericInterface::PropertyModified);
+    QVERIFY(changes.contains(QStringLiteral("mountPoint")));
+    QCOMPARE(changes[QStringLiteral("mountPoint")], (int)Solid::GenericInterface::PropertyModified);
 
     // Second one is a "PropertyAdded" for "hactar"
     changes = property_changed.at(1).at(0).value<QMap<QString, int>>();
     QCOMPARE(changes.count(), 1);
-    QVERIFY(changes.contains("hactar"));
-    QCOMPARE(changes["hactar"], (int)Solid::GenericInterface::PropertyAdded);
+    QVERIFY(changes.contains(QStringLiteral("hactar")));
+    QCOMPARE(changes[QStringLiteral("hactar")], (int)Solid::GenericInterface::PropertyAdded);
 
     // Third one is a "PropertyRemoved" for "hactar"
     changes = property_changed.at(2).at(0).value<QMap<QString, int>>();
     QCOMPARE(changes.count(), 1);
-    QVERIFY(changes.contains("hactar"));
-    QCOMPARE(changes["hactar"], (int)Solid::GenericInterface::PropertyRemoved);
+    QVERIFY(changes.contains(QStringLiteral("hactar")));
+    QCOMPARE(changes[QStringLiteral("hactar")], (int)Solid::GenericInterface::PropertyRemoved);
 
     // Only one condition has been raised in the device
     QCOMPARE(condition_raised.count(), 1);
 
     // It must be identical to the condition we raised by hand
-    QCOMPARE(condition_raised.at(0).at(0).toString(), QString("Floppy Closed"));
-    QCOMPARE(condition_raised.at(0).at(1).toString(), QString("Why not?"));
+    QCOMPARE(condition_raised.at(0).at(0).toString(), QStringLiteral("Floppy Closed"));
+    QCOMPARE(condition_raised.at(0).at(1).toString(), QStringLiteral("Why not?"));
 }
 
 void SolidHwTest::testDeviceExistence()
 {
-    QCOMPARE(Solid::Device("/org/kde/solid/fakehw/platform_floppy_0_storage_virt_volume").isValid(), true);
-    QCOMPARE(Solid::Device("/org/kde/solid/fakehw/volume_label_SOLIDMAN_BEGINS").isValid(), true);
+    QCOMPARE(Solid::Device(QStringLiteral("/org/kde/solid/fakehw/platform_floppy_0_storage_virt_volume")).isValid(), true);
+    QCOMPARE(Solid::Device(QStringLiteral("/org/kde/solid/fakehw/volume_label_SOLIDMAN_BEGINS")).isValid(), true);
 
     // Note the extra space
-    QCOMPARE(Solid::Device("/org/kde/solid/fakehw/computer ").isValid(), false);
-    QCOMPARE(Solid::Device("#'({(]").isValid(), false);
+    QCOMPARE(Solid::Device(QStringLiteral("/org/kde/solid/fakehw/computer ")).isValid(), false);
+    QCOMPARE(Solid::Device(QStringLiteral("#'({(]")).isValid(), false);
     QCOMPARE(Solid::Device(QString()).isValid(), false);
 
     // Now try to see if isValid() changes on plug/unplug events
-    Solid::Device cpu("/org/kde/solid/fakehw/acpi_CPU0");
+    Solid::Device cpu(QStringLiteral("/org/kde/solid/fakehw/acpi_CPU0"));
     QVERIFY(cpu.isValid());
-    fakeManager->unplug("/org/kde/solid/fakehw/acpi_CPU0");
+    fakeManager->unplug(QStringLiteral("/org/kde/solid/fakehw/acpi_CPU0"));
     QVERIFY(!cpu.isValid());
-    fakeManager->plug("/org/kde/solid/fakehw/acpi_CPU0");
+    fakeManager->plug(QStringLiteral("/org/kde/solid/fakehw/acpi_CPU0"));
     QVERIFY(cpu.isValid());
 }
 
 void SolidHwTest::testDeviceInterfaces()
 {
-    Solid::Device cpu("/org/kde/solid/fakehw/acpi_CPU0");
+    Solid::Device cpu(QStringLiteral("/org/kde/solid/fakehw/acpi_CPU0"));
 
     Solid::DeviceInterface *iface = cpu.asDeviceInterface(Solid::DeviceInterface::Processor);
     Solid::DeviceInterface *processor = cpu.as<Solid::Processor>();
@@ -243,24 +245,24 @@ void SolidHwTest::testDeviceInterfaces()
     QVERIFY(iface != nullptr);
     QCOMPARE(iface, processor);
 
-    Solid::Device cpu2("/org/kde/solid/fakehw/acpi_CPU0");
+    Solid::Device cpu2(QStringLiteral("/org/kde/solid/fakehw/acpi_CPU0"));
     QCOMPARE(cpu.as<Solid::Processor>(), cpu2.as<Solid::Processor>());
     QCOMPARE(cpu.as<Solid::GenericInterface>(), cpu2.as<Solid::GenericInterface>());
 
     QPointer<Solid::Processor> p = cpu.as<Solid::Processor>();
     QVERIFY(p != nullptr);
-    fakeManager->unplug("/org/kde/solid/fakehw/acpi_CPU0");
+    fakeManager->unplug(QStringLiteral("/org/kde/solid/fakehw/acpi_CPU0"));
     QVERIFY(p == nullptr);
-    fakeManager->plug("/org/kde/solid/fakehw/acpi_CPU0");
+    fakeManager->plug(QStringLiteral("/org/kde/solid/fakehw/acpi_CPU0"));
 
     QPointer<Solid::StorageVolume> v;
     QPointer<Solid::StorageVolume> v2;
     {
-        Solid::Device partition("/org/kde/solid/fakehw/volume_uuid_f00ba7");
+        Solid::Device partition(QStringLiteral("/org/kde/solid/fakehw/volume_uuid_f00ba7"));
         v = partition.as<Solid::StorageVolume>();
         QVERIFY(v != nullptr);
         {
-            Solid::Device partition2("/org/kde/solid/fakehw/volume_uuid_f00ba7");
+            Solid::Device partition2(QStringLiteral("/org/kde/solid/fakehw/volume_uuid_f00ba7"));
             v2 = partition2.as<Solid::StorageVolume>();
             QVERIFY(v2 != nullptr);
             QVERIFY(v == v2);
@@ -270,10 +272,10 @@ void SolidHwTest::testDeviceInterfaces()
     }
     QVERIFY(v != nullptr);
     QVERIFY(v2 != nullptr);
-    fakeManager->unplug("/org/kde/solid/fakehw/volume_uuid_f00ba7");
+    fakeManager->unplug(QStringLiteral("/org/kde/solid/fakehw/volume_uuid_f00ba7"));
     QVERIFY(v == nullptr);
     QVERIFY(v2 == nullptr);
-    fakeManager->plug("/org/kde/solid/fakehw/volume_uuid_f00ba7");
+    fakeManager->plug(QStringLiteral("/org/kde/solid/fakehw/volume_uuid_f00ba7"));
 }
 
 void SolidHwTest::testDeviceInterfaceIntrospection_data()
@@ -305,7 +307,7 @@ void SolidHwTest::testDeviceInterfaceIntrospection()
 void SolidHwTest::testDeviceInterfaceIntrospectionCornerCases()
 {
     QCOMPARE(Solid::DeviceInterface::typeToString((Solid::DeviceInterface::Type)-1), QString());
-    QCOMPARE((int)Solid::DeviceInterface::stringToType("blup"), -1);
+    QCOMPARE((int)Solid::DeviceInterface::stringToType(QStringLiteral("blup")), -1);
 }
 
 static QStringList to_string_list(const QList<Solid::Device> &list)
@@ -320,29 +322,29 @@ static QStringList to_string_list(const QList<Solid::Device> &list)
 
 void SolidHwTest::testInvalidPredicate()
 {
-    QString str_pred = "[[Processor.maxSpeed == 3201 AND Processor.canChangeFrequency == false] OR StorageVolume.mountPoint == '/media/blup']";
+    QString str_pred = QStringLiteral("[[Processor.maxSpeed == 3201 AND Processor.canChangeFrequency == false] OR StorageVolume.mountPoint == '/media/blup']");
     // Since str_pred is canonicalized, fromString().toString() should be invariant
     QCOMPARE(Solid::Predicate::fromString(str_pred).toString(), str_pred);
 
     // Invalid predicate
-    str_pred = "[StorageVolume.ignored == false AND OpticalDisc.isBlank == true AND OpticalDisc.discType & 'CdRecordable|CdRewritable']";
+    str_pred = QStringLiteral("[StorageVolume.ignored == false AND OpticalDisc.isBlank == true AND OpticalDisc.discType & 'CdRecordable|CdRewritable']");
     QVERIFY(!Solid::Predicate::fromString(str_pred).isValid());
 }
 
 void SolidHwTest::testPredicate()
 {
-    Solid::Device dev("/org/kde/solid/fakehw/acpi_CPU0");
+    Solid::Device dev(QStringLiteral("/org/kde/solid/fakehw/acpi_CPU0"));
     /* clang-format off */
-    Solid::Predicate p1 = (Solid::Predicate(Solid::DeviceInterface::Processor, "maxSpeed", 3200)
-                           & Solid::Predicate(Solid::DeviceInterface::Processor, "canChangeFrequency", true));
-    Solid::Predicate p2 = Solid::Predicate(Solid::DeviceInterface::Processor, "maxSpeed", 3200)
-                          & Solid::Predicate(Solid::DeviceInterface::Processor, "canChangeFrequency", false);
-    Solid::Predicate p3 = Solid::Predicate(Solid::DeviceInterface::Processor, "maxSpeed", 3201)
-                          | Solid::Predicate(Solid::DeviceInterface::Processor, "canChangeFrequency", true);
-    Solid::Predicate p4 = Solid::Predicate(Solid::DeviceInterface::Processor, "maxSpeed", 3201)
-                          | Solid::Predicate(Solid::DeviceInterface::Processor, "canChangeFrequency", false);
+    Solid::Predicate p1 = (Solid::Predicate(Solid::DeviceInterface::Processor, QStringLiteral("maxSpeed"), 3200)
+                           & Solid::Predicate(Solid::DeviceInterface::Processor, QStringLiteral("canChangeFrequency"), true));
+    Solid::Predicate p2 = Solid::Predicate(Solid::DeviceInterface::Processor, QStringLiteral("maxSpeed"), 3200)
+                          & Solid::Predicate(Solid::DeviceInterface::Processor, QStringLiteral("canChangeFrequency"), false);
+    Solid::Predicate p3 = Solid::Predicate(Solid::DeviceInterface::Processor, QStringLiteral("maxSpeed"), 3201)
+                          | Solid::Predicate(Solid::DeviceInterface::Processor, QStringLiteral("canChangeFrequency"), true);
+    Solid::Predicate p4 = Solid::Predicate(Solid::DeviceInterface::Processor, QStringLiteral("maxSpeed"), 3201)
+                          | Solid::Predicate(Solid::DeviceInterface::Processor, QStringLiteral("canChangeFrequency"), false);
     Solid::Predicate p5 =
-        Solid::Predicate::fromString("[[Processor.maxSpeed == 3201 AND Processor.canChangeFrequency == false] OR StorageVolume.mountPoint == '/media/blup']");
+        Solid::Predicate::fromString(QStringLiteral("[[Processor.maxSpeed == 3201 AND Processor.canChangeFrequency == false] OR StorageVolume.mountPoint == '/media/blup']"));
     /* clang-format on */
 
     QVERIFY(p1.matches(dev));
@@ -350,18 +352,18 @@ void SolidHwTest::testPredicate()
     QVERIFY(p3.matches(dev));
     QVERIFY(!p4.matches(dev));
 
-    Solid::Predicate p6 = Solid::Predicate::fromString("StorageVolume.usage == 'Other'");
-    Solid::Predicate p7 = Solid::Predicate::fromString(QString("StorageVolume.usage == %1").arg((int)Solid::StorageVolume::Other));
+    Solid::Predicate p6 = Solid::Predicate::fromString(QStringLiteral("StorageVolume.usage == 'Other'"));
+    Solid::Predicate p7 = Solid::Predicate::fromString(QStringLiteral("StorageVolume.usage == %1").arg((int)Solid::StorageVolume::Other));
     QVERIFY(!p6.matches(dev));
     QVERIFY(!p7.matches(dev));
-    dev = Solid::Device("/org/kde/solid/fakehw/volume_part2_size_1024");
+    dev = Solid::Device(QStringLiteral("/org/kde/solid/fakehw/volume_part2_size_1024"));
     QVERIFY(p6.matches(dev));
     QVERIFY(p7.matches(dev));
 
     QList<Solid::Device> list;
 
     QStringList cpuSet;
-    cpuSet << QString("/org/kde/solid/fakehw/acpi_CPU0") << QString("/org/kde/solid/fakehw/acpi_CPU1");
+    cpuSet << QStringLiteral("/org/kde/solid/fakehw/acpi_CPU0") << QStringLiteral("/org/kde/solid/fakehw/acpi_CPU1");
 
     list = Solid::Device::listFromQuery(p1);
     QCOMPARE(list.size(), 2);
@@ -377,80 +379,80 @@ void SolidHwTest::testPredicate()
     list = Solid::Device::listFromQuery(p4);
     QCOMPARE(list.size(), 0);
 
-    list = Solid::Device::listFromQuery("[Processor.canChangeFrequency==true AND Processor.number==1]");
+    list = Solid::Device::listFromQuery(QStringLiteral("[Processor.canChangeFrequency==true AND Processor.number==1]"));
     QCOMPARE(list.size(), 1);
-    QCOMPARE(list.at(0).udi(), QString("/org/kde/solid/fakehw/acpi_CPU1"));
+    QCOMPARE(list.at(0).udi(), QStringLiteral("/org/kde/solid/fakehw/acpi_CPU1"));
 
     // writeSpeeds is a QList, make sure we can match a single element.
-    list = Solid::Device::listFromQuery("[OpticalDrive.writeSpeeds==2117 AND OpticalDrive.removable==true]");
+    list = Solid::Device::listFromQuery(QStringLiteral("[OpticalDrive.writeSpeeds==2117 AND OpticalDrive.removable==true]"));
     QCOMPARE(list.size(), 1);
-    QCOMPARE(list.at(0).udi(), QString("/org/kde/solid/fakehw/storage_model_solid_writer"));
+    QCOMPARE(list.at(0).udi(), QStringLiteral("/org/kde/solid/fakehw/storage_model_solid_writer"));
 }
 
 void SolidHwTest::testQueryStorageVolumeOrProcessor()
 {
-    auto list = Solid::Device::listFromQuery("[Processor.number==1 OR IS StorageVolume]");
+    auto list = Solid::Device::listFromQuery(QStringLiteral("[Processor.number==1 OR IS StorageVolume]"));
     QCOMPARE(list.size(), 13);
 
     // make sure predicate case-insensitiveness is sane
-    list = Solid::Device::listFromQuery("[Processor.number==1 or is StorageVolume]");
+    list = Solid::Device::listFromQuery(QStringLiteral("[Processor.number==1 or is StorageVolume]"));
     QCOMPARE(list.size(), 13);
-    list = Solid::Device::listFromQuery("[Processor.number==1 oR Is StorageVolume]");
+    list = Solid::Device::listFromQuery(QStringLiteral("[Processor.number==1 oR Is StorageVolume]"));
     QCOMPARE(list.size(), 13);
-    QStringList expected{"/org/kde/solid/fakehw/acpi_CPU1",
-                         "/org/kde/solid/fakehw/platform_floppy_0_storage_virt_volume",
-                         "/org/kde/solid/fakehw/volume_0000_unmounted_storage",
-                         "/org/kde/solid/fakehw/volume_label_SOLIDMAN_BEGINS",
-                         "/org/kde/solid/fakehw/volume_part1_size_993284096",
-                         "/org/kde/solid/fakehw/volume_part2_size_1024",
-                         "/org/kde/solid/fakehw/volume_part5_size_1048576",
-                         "/org/kde/solid/fakehw/volume_uuid_5011",
-                         "/org/kde/solid/fakehw/volume_uuid_c0ffee",
-                         "/org/kde/solid/fakehw/volume_uuid_cleartext_data_0123",
-                         "/org/kde/solid/fakehw/volume_uuid_encrypted_0123",
-                         "/org/kde/solid/fakehw/volume_uuid_f00ba7",
-                         "/org/kde/solid/fakehw/volume_uuid_feedface"};
+    QStringList expected{QStringLiteral("/org/kde/solid/fakehw/acpi_CPU1"),
+                         QStringLiteral("/org/kde/solid/fakehw/platform_floppy_0_storage_virt_volume"),
+                         QStringLiteral("/org/kde/solid/fakehw/volume_0000_unmounted_storage"),
+                         QStringLiteral("/org/kde/solid/fakehw/volume_label_SOLIDMAN_BEGINS"),
+                         QStringLiteral("/org/kde/solid/fakehw/volume_part1_size_993284096"),
+                         QStringLiteral("/org/kde/solid/fakehw/volume_part2_size_1024"),
+                         QStringLiteral("/org/kde/solid/fakehw/volume_part5_size_1048576"),
+                         QStringLiteral("/org/kde/solid/fakehw/volume_uuid_5011"),
+                         QStringLiteral("/org/kde/solid/fakehw/volume_uuid_c0ffee"),
+                         QStringLiteral("/org/kde/solid/fakehw/volume_uuid_cleartext_data_0123"),
+                         QStringLiteral("/org/kde/solid/fakehw/volume_uuid_encrypted_0123"),
+                         QStringLiteral("/org/kde/solid/fakehw/volume_uuid_f00ba7"),
+                         QStringLiteral("/org/kde/solid/fakehw/volume_uuid_feedface")};
     QCOMPARE(to_string_list(list), expected);
 
-    list = Solid::Device::listFromQuery("[IS Processor OR IS StorageVolume]");
+    list = Solid::Device::listFromQuery(QStringLiteral("[IS Processor OR IS StorageVolume]"));
     QCOMPARE(list.size(), 14);
-    expected.prepend("/org/kde/solid/fakehw/acpi_CPU0");
+    expected.prepend(QStringLiteral("/org/kde/solid/fakehw/acpi_CPU0"));
     QCOMPARE(to_string_list(list), expected);
 }
 
 void SolidHwTest::testQueryStorageVolumeOrStorageAccess()
 {
     // the query from KFilePlacesModel
-    const auto list = Solid::Device::listFromQuery(
+    const auto list = Solid::Device::listFromQuery(QStringLiteral( //
         "[[[[ StorageVolume.ignored == false AND [ StorageVolume.usage == 'FileSystem' OR StorageVolume.usage == 'Encrypted' ]]"
         " OR "
         "[ IS StorageAccess AND StorageDrive.driveType == 'Floppy' ]]"
         " OR "
         "OpticalDisc.availableContent & 'Audio' ]"
         " OR "
-        "StorageAccess.ignored == false ]");
-    const QStringList expected{"/org/kde/solid/fakehw/fstab/thehost/solidpath",
-                               "/org/kde/solid/fakehw/platform_floppy_0_storage_virt_volume",
-                               "/org/kde/solid/fakehw/volume_part1_size_993284096",
-                               "/org/kde/solid/fakehw/volume_uuid_5011",
-                               "/org/kde/solid/fakehw/volume_uuid_f00ba7"};
+        "StorageAccess.ignored == false ]"));
+    const QStringList expected{QStringLiteral("/org/kde/solid/fakehw/fstab/thehost/solidpath"),
+                               QStringLiteral("/org/kde/solid/fakehw/platform_floppy_0_storage_virt_volume"),
+                               QStringLiteral("/org/kde/solid/fakehw/volume_part1_size_993284096"),
+                               QStringLiteral("/org/kde/solid/fakehw/volume_uuid_5011"),
+                               QStringLiteral("/org/kde/solid/fakehw/volume_uuid_f00ba7")};
     QCOMPARE(to_string_list(list), expected);
 }
 
 void SolidHwTest::testQueryWithParentUdi()
 {
-    QString parentUdi = "/org/kde/solid/fakehw/storage_model_solid_reader";
+    QString parentUdi = QStringLiteral("/org/kde/solid/fakehw/storage_model_solid_reader");
     Solid::DeviceInterface::Type ifaceType = Solid::DeviceInterface::Unknown;
     QCOMPARE(fakeManager->devicesFromQuery(parentUdi, ifaceType).size(), 1);
-    QCOMPARE(fakeManager->devicesFromQuery(parentUdi, ifaceType).at(0), QString("/org/kde/solid/fakehw/volume_label_SOLIDMAN_BEGINS"));
+    QCOMPARE(fakeManager->devicesFromQuery(parentUdi, ifaceType).at(0), QStringLiteral("/org/kde/solid/fakehw/volume_label_SOLIDMAN_BEGINS"));
 
     ifaceType = Solid::DeviceInterface::Processor;
     QCOMPARE(fakeManager->devicesFromQuery(parentUdi, ifaceType).size(), 0);
 
-    parentUdi = "/org/kde/solid/fakehw/computer";
+    parentUdi = QStringLiteral("/org/kde/solid/fakehw/computer");
     QCOMPARE(fakeManager->devicesFromQuery(parentUdi, ifaceType).size(), 2);
-    QCOMPARE(fakeManager->devicesFromQuery(parentUdi, ifaceType).at(0), QString("/org/kde/solid/fakehw/acpi_CPU0"));
-    QCOMPARE(fakeManager->devicesFromQuery(parentUdi, ifaceType).at(1), QString("/org/kde/solid/fakehw/acpi_CPU1"));
+    QCOMPARE(fakeManager->devicesFromQuery(parentUdi, ifaceType).at(0), QStringLiteral("/org/kde/solid/fakehw/acpi_CPU0"));
+    QCOMPARE(fakeManager->devicesFromQuery(parentUdi, ifaceType).at(1), QStringLiteral("/org/kde/solid/fakehw/acpi_CPU1"));
 }
 
 void SolidHwTest::testListFromTypeProcessor()
@@ -458,13 +460,13 @@ void SolidHwTest::testListFromTypeProcessor()
     const auto ifaceType = Solid::DeviceInterface::Processor;
     const auto list = Solid::Device::listFromType(ifaceType, QString());
     QCOMPARE(list.size(), 2);
-    QCOMPARE(list.at(0).udi(), QString("/org/kde/solid/fakehw/acpi_CPU0"));
-    QCOMPARE(list.at(1).udi(), QString("/org/kde/solid/fakehw/acpi_CPU1"));
+    QCOMPARE(list.at(0).udi(), QStringLiteral("/org/kde/solid/fakehw/acpi_CPU0"));
+    QCOMPARE(list.at(1).udi(), QStringLiteral("/org/kde/solid/fakehw/acpi_CPU1"));
 }
 
 void SolidHwTest::testListFromTypeInvalid()
 {
-    const auto list = Solid::Device::listFromQuery("blup", QString());
+    const auto list = Solid::Device::listFromQuery(QStringLiteral("blup"), QString());
     QCOMPARE(list.size(), 0);
 }
 
@@ -472,7 +474,7 @@ void SolidHwTest::testSetupTeardown()
 {
     Solid::StorageAccess *access;
     {
-        Solid::Device device("/org/kde/solid/fakehw/volume_part1_size_993284096");
+        Solid::Device device(QStringLiteral("/org/kde/solid/fakehw/volume_part1_size_993284096"));
         access = device.as<Solid::StorageAccess>();
     }
 
@@ -529,4 +531,32 @@ void SolidHwTest::testStorageAccessFromPath_data()
     QTest::addRow("LUKS")            << QStringLiteral("/data")       << QStringLiteral("volume_uuid_cleartext_data_0123");
 }
 
+void SolidHwTest::testDeviceVendorProduct_data()
+{
+    QTest::addColumn<QString>("udi");
+    QTest::addColumn<QString>("expectedVendor");
+    QTest::addColumn<QString>("expectedProduct");
+
+    QTest::addRow("Processor") << QStringLiteral("/org/kde/solid/fakehw/acpi_CPU0") << QStringLiteral("Acme Corporation")
+                               << QStringLiteral("Solid Processor #0");
+    QTest::addRow("Ethernet adapter") << QStringLiteral("/org/kde/solid/fakehw/pci_10ec_8168") << QStringLiteral("ReallyChip Corporation")
+                                      << QStringLiteral("Gigabit Ethernet Controller");
+    QTest::addRow("WiFi adapter") << QStringLiteral("/org/kde/solid/fakehw/pci_8086_2526") << QStringLiteral("Acme Corporation")
+                                  << QStringLiteral("Wireless Network Adapter");
+    QTest::addRow("Storage device") << QStringLiteral("/org/kde/solid/fakehw/storage_serial_HD56890I") << QStringLiteral("Acme Corporation")
+                                    << QStringLiteral("HD250GB");
+}
+
+void SolidHwTest::testDeviceVendorProduct()
+{
+    QFETCH(QString, udi);
+    QFETCH(QString, expectedVendor);
+    QFETCH(QString, expectedProduct);
+
+    Solid::Device device(udi);
+    QVERIFY(device.isValid());
+    QCOMPARE(device.vendor(), expectedVendor);
+    QCOMPARE(device.product(), expectedProduct);
+}
+
 #include "solidhwtest.moc"
