@@ -7,10 +7,10 @@
 #ifndef SOLID_DEVICE_P_H
 #define SOLID_DEVICE_P_H
 
-#include <QObject>
-#include <QSharedData>
-#include <QPointer>
 #include <QMap>
+#include <QObject>
+#include <QPointer>
+#include <QSharedData>
 
 #include <ifaces/device.h>
 
@@ -25,7 +25,7 @@ class DevicePrivate : public QObject, public QSharedData
     Q_OBJECT
 public:
     explicit DevicePrivate(const QString &udi);
-    ~DevicePrivate();
+    ~DevicePrivate() override;
 
     QString udi() const
     {
@@ -34,20 +34,17 @@ public:
 
     Ifaces::Device *backendObject() const
     {
-        return m_backendObject.data();
+        return m_backendObject.get();
     }
-    void setBackendObject(Ifaces::Device *object);
+    void setBackendObject(std::unique_ptr<Ifaces::Device> &&object);
 
     DeviceInterface *interface(const DeviceInterface::Type &type) const;
-    void setInterface(const DeviceInterface::Type &type, DeviceInterface *interface);
-
-public Q_SLOTS:
-    void _k_destroyed(QObject *object);
+    void setInterface(const DeviceInterface::Type &type, std::unique_ptr<DeviceInterface> &&interface);
 
 private:
     QString m_udi;
-    QPointer<Ifaces::Device> m_backendObject;
-    QMap<DeviceInterface::Type, QPointer<DeviceInterface>> m_ifaces;
+    std::unique_ptr<Ifaces::Device> m_backendObject;
+    std::map<DeviceInterface::Type, std::unique_ptr<DeviceInterface>> m_ifaces;
 };
 }
 
